Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
var DefaultByteOrder = binary.LittleEndian
Functions ¶
func LoadDATFile ¶
LoadDATFile loads binary file found at path and populates obj instance.
func SaveDATFile ¶
SaveDATFile saves a single data to its original location on disk file if the content has changed. name is the path inside the game directory.
func Unmarshall ¶
Unmarshall decodes binary data from a buffer into a struct.
Types ¶
type NullString ¶
type NullString string
NullString is a null byte terminated string. When read from binary data via restruct, the full fixed-size byte field (including null bytes) is stored. Use String() to get the value truncated at the first null byte.
func (NullString) String ¶
func (s NullString) String() string
String returns the string value, truncated at the first null byte.
Click to show internal directories.
Click to hide internal directories.